@@ -1,4 +1,5 @@
 from fwiffos.core import version
+from fwiffos.cli.sudo import LetUs
 
 class Calculator(object):
 
@@ -16,18 +17,18 @@ class FS(object):
     def ls(self, cwd='/'):
         print(self.filesystem[cwd])
 
-    def commands(self):
-        return self._commands
-
 class Commands(object):
     def __init__(self):
         fs = FS()
         calc = Calculator()
+        sudo = LetUs()
         self._version = version
         self.__commands = {
             'ls': fs.ls,
             'add': calc.add,
             'mult': calc.multiply,
+            'sudo': sudo.letus,
+            'letus': sudo.letus,
         }
 
     def exec(self):
